def matrix():
    print(" Year: 2014 \n Board: CBSE \n CGPA: 10 \n School: Wisdom Public School \n City: Aligarh, Uttar Pradesh")


def secondary():
    print(" Year: 2016 \n Board: CBSE \n Branch: PCM \n Percentge: 90.2% \n School: Sunbeam Academy, Samneghat \n City: Varansi, Uttar Pradesh")


def undergraduation():
    print(" Current_Semester: 6th \n Branch: Information Technology \n CPI: 8.42 \n College: Motilal Nehru National Institute of Technology \n City: Prayagraj, Uttar Pradesh")
