def introduction():
    return(
        "Hello, it's m1key"+"\n" + "Welcome to the m1key WORLD..."+"\n" +
        "I am Python Programmer as well as React Developer with fare bit of knowledge of Machine Learning"+"\n"
    )
